@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20250731';
+our $VERSION = '0.20250829';
 
-# Table last modified: 2025-07-31
+# Table last modified: 2025-08-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -67,7 +67,7 @@ our %ZIP_TABLE = (
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|55|7[025]|3[029]|1[01467])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
-    '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
+    '064' => '(?:8(?:5(?:1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|2[1-36]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|67|1[025]|7[07]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
@@ -107,11 +107,11 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|1[0-2479]|2[0146]|8[489]|3[037])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:5[0-356]|1[023579]|6[356]|7[07-9]|8[013689]|3[02358]|2[1-58]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:5[0-356]|1[023579]|6[356]|7[07-9]|8[013689]|3[02358]|2[1-58]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|4[0349]|2[0-469]|6[078])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-47-9]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|4[0-7]|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[125-7]|3[1-3689]|2[238]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[2358]|3[1-3689]|0[267]|1[125-8]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|0[6-8]|1[2-6]|2[235]|3[36])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -140,7 +140,7 @@ our %ZIP_TABLE = (
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|55|67|1[025]|0[13]|8[058]|7[67]|4[034])|6(?:[03]1|[15]0|77|2[03]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|5[1-5]|1[0-24-6]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[246-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|2[26]|6[37]|0[1-357-9]|7[57]|8[578]|5[1-5]|1[0-24-6]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[246-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:[34]\d|0[2-7]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|1[02568]|3[01679])|6(?:01|40|1[06]|8[78]|6[025689]|2[026]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
@@ -155,7 +155,7 @@ our %ZIP_TABLE = (
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:[28]0|02|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
     '164' => '(?:8(?:5(?:[37]0|55|4[015]|2[25]|6[67]|8[58]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
-    '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
+    '166' => '(?:85(?:20|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
     '168' => '(?:8(?:5(?:[6-8]0|48|1[0-26]|5[058]|2[05]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
     '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:[23]9|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|3[0689]|[24][0-3]|6[0-7]|5[89]|8[0568]|0[127-9])|6(?:53|60|0[149]|1[1-6]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|3[0689]|2[0-35]|4[0-3]|6[0-7]|5[89]|8[0568]|0[127-9])|6(?:53|60|0[149]|1[1-6]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:5[028]|1[015]|3[03]|8[056]|6[1-6]|7[57]|0[157-9]|2[035])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -231,7 +231,7 @@ our %ZIP_TABLE = (
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
     '251' => '(?:8(?:5(?:22|70|4[03]|1[0-35]|8[018]|5[0158]|3[0134]|6[067]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|2[0-25]|6[09]|8[025-8]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|2[0-25]|6[09]|8[025-8]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|3[89]|7[02]|8[35]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -294,17 +294,17 @@ our %ZIP_TABLE = (
     '318' => '(?:85(?:11|0[15]))',
     '319' => '(?:(?:1(?:1(?:8[248]|9[24-7])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
-    '321' => '(?:(?:3(?:29[235-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
+    '321' => '(?:(?:3(?:29[2-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86)|75[56])|019[24]|1192))',
     '324' => '(?:(?:8(?:5(?:[24]0|01|85|1[06]|5[015])|6(?:25|86|4[12])|765)|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:11|72|85|5[058]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
-    '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
+    '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[058]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|7(?:9[1-367]|3[19]|2[07]|1[0357])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:30|77|0[13]|1[01])|1(?:09|1[01])|0(?:11|45))|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|86|0[13])|7(?:08|10|77))))',
-    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
+    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:25|33|58|8[6-8])|701)|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
@@ -425,7 +425,7 @@ our %ZIP_TABLE = (
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:01|40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|1[0-28])|6(?:[28]6|62|0[18])|7(?:58|77|0[14])))',
-    '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[125-9]|6[05]|0[1-689])|651))',
+    '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[125-9]|6[05]|0[1-35689])|651))',
     '455' => '(?:8(?:5(?:[458]5|60|77|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|7(?:58|77)))',
     '456' => '(?:8(?:5(?:23|30|44|0[1-3]|6[07]|1[16]|8[0578]|5[56])|6(?:20|91|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:22|45|77|3[0-35]|5[158]|1[0-25]|6[067]|8[58]|0[18])|71[12]))',
@@ -457,7 +457,7 @@ our %ZIP_TABLE = (
     '483' => '(?:8(?:5(?:55|0[257])|7(?:14|0[14])))',
     '484' => '(?:8(?:5(?:0[1-8]|1[0-2])|609))',
     '485' => '(?:8(?:5(?:05|1[0-26]|5[0-257]|2[0-3]|3[013]|6[1256])|65[0-5]|750))',
-    '486' => '(?:8(?:5(?:01|40|67|75|2[23]|1[015]|8[58]|5[05])|6[68]6))',
+    '486' => '(?:8(?:5(?:01|40|67|2[23]|1[015]|8[58]|5[05]|7[57])|6[68]6))',
     '487' => '(?:8(?:6(?:22|50)|501))',
     '488' => '(?:8(?:5(?:[58]5|01|20|78)|6(?:55|66|8[68])))',
     '489' => '(?:8(?:5(?:20|67|85|5[05]|1[01])|6(?:[58]0|11|4[25])|450|701))',
@@ -541,7 +541,7 @@ our %ZIP_TABLE = (
     '571' => '(?:8(?:5(?:[45]5|33|67|71|0[1-46-8]|8[05])|6(?:[24]0|33|86)))',
     '572' => '(?:85(?:4[04]|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
     '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[0-2])|6(?:54|66))|10(?:[34]0|1[03]|0[1478])|019[356]))',
-    '574' => '(?:85(?:[58]5|01|3[0-4]))',
+    '574' => '(?:85(?:[58]5|01|3[0-5]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
     '577' => '(?:8(?:5(?:40|3[37]|0[2359]|5[01458]|8[1258]|6[067]|7[57]|2[0-2]|1[01])|666))',
@@ -876,7 +876,7 @@ our %ZIP_TABLE = (
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|601)|0(?:29[378]|[13]98)))',
     '918' => '(?:8(?:5(?:6[05-7]|4[03]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[2578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[1-35-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:9[23568]|8[235-8])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|4[14-689]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
